@@ -8,8 +8,8 @@ from selenium.common.exceptions import TimeoutException
 from pydub import AudioSegment
 from typing import Optional
 import speech_recognition as sr
-import requests
 import tempfile
+import requests
 import random
 import time
 import os
@@ -203,7 +203,7 @@ class RecaptchaSolver:
                 os.remove(path)
 
         # Write transcribed text to iframe's input box
-        response_textbox = self._driver.find_element(by='id', value='audio-response')
+        response_textbox = self._driver.find_element(By.ID, 'audio-response')
 
         if self._delay_config:
             self._delay_config.delay_before_type_answer()
